BaseEntity class abstract

Base entity class that extends Object

Implementers

Constructors

BaseEntity()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Get the string representation
override

Operators

operator ==(Object other) bool
The equality operator.
inherited