User class

User class that extends BaseEntity and implements Comparable

Inheritance
Implemented types

Constructors

User({required String id, required String name, required int age})

Properties

age int
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(User other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Get the string representation
override

Operators

operator ==(Object other) bool
The equality operator.
inherited