UserRepository class

Repository for managing users with a sorted list

Constructors

UserRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users SortedList<User>
final

Methods

addUser(User user) → void
Add a user to the repository
findByAge(int age) User?
Find user by age
getAllUsers() List<User>
Get all users sorted by age
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited