parse_mermaid_dart library
Classes
- ClassInfo
- Information about a Dart class extracted from the AST.
- ParseDart
- Main entry point for analyzing a Dart project.
- ParseResult
- Result of analyzing a Dart project.
Enums
- ClassKind
- Enum representing the kind of class or type declaration.
- RelationshipKind
- Enum representing different types of relationships between classes.